# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) Python Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------
# pylint: disable=wrong-import-position

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from ._patch import *  # pylint: disable=unused-wildcard-import

from ._operations import Operations  # type: ignore
from ._operations import BackupResourceStorageConfigsNonCRROperations  # type: ignore
from ._operations import BMSPrepareDataMoveOperationResultOperations  # type: ignore
from ._operations import BackupResourceVaultConfigsOperations  # type: ignore
from ._operations import BackupResourceEncryptionConfigsOperations  # type: ignore
from ._operations import ProtectedItemsOperations  # type: ignore
from ._operations import BackupsOperations  # type: ignore
from ._operations import RecoveryPointsRecommendedForMoveOperations  # type: ignore
from ._operations import ProtectedItemOperationStatusesOperations  # type: ignore
from ._operations import ProtectedItemOperationResultsOperations  # type: ignore
from ._operations import ProtectionContainersOperations  # type: ignore
from ._operations import BackupWorkloadItemsOperations  # type: ignore
from ._operations import ProtectionContainerOperationResultsOperations  # type: ignore
from ._operations import RecoveryPointsOperations  # type: ignore
from ._operations import RestoresOperations  # type: ignore
from ._operations import ItemLevelRecoveryConnectionsOperations  # type: ignore
from ._operations import ProtectionPoliciesOperations  # type: ignore
from ._operations import BackupPoliciesOperations  # type: ignore
from ._operations import ProtectionPolicyOperationResultsOperations  # type: ignore
from ._operations import ProtectionPolicyOperationStatusesOperations  # type: ignore
from ._operations import JobDetailsOperations  # type: ignore
from ._operations import BackupJobsOperations  # type: ignore
from ._operations import JobCancellationsOperations  # type: ignore
from ._operations import JobOperationResultsOperations  # type: ignore
from ._operations import ExportJobsOperationResultsOperations  # type: ignore
from ._operations import BackupEnginesOperations  # type: ignore
from ._operations import ResourceGuardProxyOperations  # type: ignore
from ._operations import ResourceGuardProxiesOperations  # type: ignore
from ._operations import BackupStatusOperations  # type: ignore
from ._operations import FeatureSupportOperations  # type: ignore
from ._operations import BackupProtectionIntentOperations  # type: ignore
from ._operations import BackupUsageSummariesOperations  # type: ignore
from ._operations import JobsOperations  # type: ignore
from ._operations import BackupProtectedItemsOperations  # type: ignore
from ._operations import ValidateOperationOperations  # type: ignore
from ._operations import ValidateOperationResultsOperations  # type: ignore
from ._operations import ValidateOperationStatusesOperations  # type: ignore
from ._operations import ProtectionContainerRefreshOperationResultsOperations  # type: ignore
from ._operations import ProtectableContainersOperations  # type: ignore
from ._operations import BackupOperationResultsOperations  # type: ignore
from ._operations import BackupOperationStatusesOperations  # type: ignore
from ._operations import BackupProtectableItemsOperations  # type: ignore
from ._operations import BackupProtectionContainersOperations  # type: ignore
from ._operations import DeletedProtectionContainersOperations  # type: ignore
from ._operations import SecurityPINsOperations  # type: ignore
from ._operations import FetchTieringCostOperations  # type: ignore
from ._operations import GetTieringCostOperationResultOperations  # type: ignore
from ._operations import TieringCostOperationStatusOperations  # type: ignore
from ._operations import ProtectionIntentOperations  # type: ignore
from ._operations import PrivateEndpointConnectionOperations  # type: ignore
from ._operations import PrivateEndpointOperations  # type: ignore
from ._operations import OperationOperations  # type: ignore
from ._operations import _RecoveryServicesBackupClientOperationsMixin  # type: ignore # pylint: disable=unused-import

from ._patch import __all__ as _patch_all
from ._patch import *
from ._patch import patch_sdk as _patch_sdk

__all__ = [
    "Operations",
    "BackupResourceStorageConfigsNonCRROperations",
    "BMSPrepareDataMoveOperationResultOperations",
    "BackupResourceVaultConfigsOperations",
    "BackupResourceEncryptionConfigsOperations",
    "ProtectedItemsOperations",
    "BackupsOperations",
    "RecoveryPointsRecommendedForMoveOperations",
    "ProtectedItemOperationStatusesOperations",
    "ProtectedItemOperationResultsOperations",
    "ProtectionContainersOperations",
    "BackupWorkloadItemsOperations",
    "ProtectionContainerOperationResultsOperations",
    "RecoveryPointsOperations",
    "RestoresOperations",
    "ItemLevelRecoveryConnectionsOperations",
    "ProtectionPoliciesOperations",
    "BackupPoliciesOperations",
    "ProtectionPolicyOperationResultsOperations",
    "ProtectionPolicyOperationStatusesOperations",
    "JobDetailsOperations",
    "BackupJobsOperations",
    "JobCancellationsOperations",
    "JobOperationResultsOperations",
    "ExportJobsOperationResultsOperations",
    "BackupEnginesOperations",
    "ResourceGuardProxyOperations",
    "ResourceGuardProxiesOperations",
    "BackupStatusOperations",
    "FeatureSupportOperations",
    "BackupProtectionIntentOperations",
    "BackupUsageSummariesOperations",
    "JobsOperations",
    "BackupProtectedItemsOperations",
    "ValidateOperationOperations",
    "ValidateOperationResultsOperations",
    "ValidateOperationStatusesOperations",
    "ProtectionContainerRefreshOperationResultsOperations",
    "ProtectableContainersOperations",
    "BackupOperationResultsOperations",
    "BackupOperationStatusesOperations",
    "BackupProtectableItemsOperations",
    "BackupProtectionContainersOperations",
    "DeletedProtectionContainersOperations",
    "SecurityPINsOperations",
    "FetchTieringCostOperations",
    "GetTieringCostOperationResultOperations",
    "TieringCostOperationStatusOperations",
    "ProtectionIntentOperations",
    "PrivateEndpointConnectionOperations",
    "PrivateEndpointOperations",
    "OperationOperations",
]
__all__.extend([p for p in _patch_all if p not in __all__])  # pyright: ignore
_patch_sdk()
