# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) Python Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------
# pylint: disable=wrong-import-position

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from ._patch import *  # pylint: disable=unused-wildcard-import


from ._models import (  # type: ignore
    ArmErrorDetail,
    AzureBackupGoalFeatureSupportRequest,
    AzureBackupServerContainer,
    AzureBackupServerEngine,
    AzureFileShareBackupRequest,
    AzureFileShareProtectableItem,
    AzureFileShareProtectionPolicy,
    AzureFileShareProvisionILRRequest,
    AzureFileShareRecoveryPoint,
    AzureFileShareRestoreRequest,
    AzureFileshareProtectedItem,
    AzureFileshareProtectedItemExtendedInfo,
    AzureIaaSClassicComputeVMContainer,
    AzureIaaSClassicComputeVMProtectableItem,
    AzureIaaSClassicComputeVMProtectedItem,
    AzureIaaSComputeVMContainer,
    AzureIaaSComputeVMProtectableItem,
    AzureIaaSComputeVMProtectedItem,
    AzureIaaSVMErrorInfo,
    AzureIaaSVMHealthDetails,
    AzureIaaSVMJob,
    AzureIaaSVMJobExtendedInfo,
    AzureIaaSVMJobTaskDetails,
    AzureIaaSVMJobV2,
    AzureIaaSVMProtectedItem,
    AzureIaaSVMProtectedItemExtendedInfo,
    AzureIaaSVMProtectionPolicy,
    AzureRecoveryServiceVaultProtectionIntent,
    AzureResourceProtectionIntent,
    AzureSQLAGWorkloadContainerProtectionContainer,
    AzureSqlContainer,
    AzureSqlProtectedItem,
    AzureSqlProtectedItemExtendedInfo,
    AzureSqlProtectionPolicy,
    AzureStorageContainer,
    AzureStorageErrorInfo,
    AzureStorageJob,
    AzureStorageJobExtendedInfo,
    AzureStorageJobTaskDetails,
    AzureStorageProtectableContainer,
    AzureVMAppContainerProtectableContainer,
    AzureVMAppContainerProtectionContainer,
    AzureVMResourceFeatureSupportRequest,
    AzureVMResourceFeatureSupportResponse,
    AzureVmWorkloadItem,
    AzureVmWorkloadProtectableItem,
    AzureVmWorkloadProtectedItem,
    AzureVmWorkloadProtectedItemExtendedInfo,
    AzureVmWorkloadProtectionPolicy,
    AzureVmWorkloadSAPAseDatabaseProtectableItem,
    AzureVmWorkloadSAPAseDatabaseProtectedItem,
    AzureVmWorkloadSAPAseDatabaseWorkloadItem,
    AzureVmWorkloadSAPAseSystemProtectableItem,
    AzureVmWorkloadSAPAseSystemWorkloadItem,
    AzureVmWorkloadSAPHanaDBInstance,
    AzureVmWorkloadSAPHanaDBInstanceProtectedItem,
    AzureVmWorkloadSAPHanaDatabaseProtectableItem,
    AzureVmWorkloadSAPHanaDatabaseProtectedItem,
    AzureVmWorkloadSAPHanaDatabaseWorkloadItem,
    AzureVmWorkloadSAPHanaHSRProtectableItem,
    AzureVmWorkloadSAPHanaScaleoutProtectableItem,
    AzureVmWorkloadSAPHanaSystemProtectableItem,
    AzureVmWorkloadSAPHanaSystemWorkloadItem,
    AzureVmWorkloadSQLAvailabilityGroupProtectableItem,
    AzureVmWorkloadSQLDatabaseProtectableItem,
    AzureVmWorkloadSQLDatabaseProtectedItem,
    AzureVmWorkloadSQLDatabaseWorkloadItem,
    AzureVmWorkloadSQLInstanceProtectableItem,
    AzureVmWorkloadSQLInstanceProtectedItem,
    AzureVmWorkloadSQLInstanceWorkloadItem,
    AzureWorkloadAutoProtectionIntent,
    AzureWorkloadBackupRequest,
    AzureWorkloadContainer,
    AzureWorkloadContainerAutoProtectionIntent,
    AzureWorkloadContainerExtendedInfo,
    AzureWorkloadErrorInfo,
    AzureWorkloadJob,
    AzureWorkloadJobExtendedInfo,
    AzureWorkloadJobTaskDetails,
    AzureWorkloadPointInTimeRecoveryPoint,
    AzureWorkloadPointInTimeRestoreRequest,
    AzureWorkloadRecoveryPoint,
    AzureWorkloadRestoreRequest,
    AzureWorkloadSAPAsePointInTimeRecoveryPoint,
    AzureWorkloadSAPAsePointInTimeRestoreRequest,
    AzureWorkloadSAPAseRecoveryPoint,
    AzureWorkloadSAPAseRestoreRequest,
    AzureWorkloadSAPHanaPointInTimeRecoveryPoint,
    AzureWorkloadSAPHanaPointInTimeRestoreRequest,
    AzureWorkloadSAPHanaPointInTimeRestoreWithRehydrateRequest,
    AzureWorkloadSAPHanaRecoveryPoint,
    AzureWorkloadSAPHanaRestoreRequest,
    AzureWorkloadSAPHanaRestoreWithRehydrateRequest,
    AzureWorkloadSQLAutoProtectionIntent,
    AzureWorkloadSQLPointInTimeRecoveryPoint,
    AzureWorkloadSQLPointInTimeRestoreRequest,
    AzureWorkloadSQLPointInTimeRestoreWithRehydrateRequest,
    AzureWorkloadSQLRecoveryPoint,
    AzureWorkloadSQLRecoveryPointExtendedInfo,
    AzureWorkloadSQLRestoreRequest,
    AzureWorkloadSQLRestoreWithRehydrateRequest,
    BEKDetails,
    BackupEngineBase,
    BackupEngineBaseResource,
    BackupEngineExtendedInfo,
    BackupManagementUsage,
    BackupRequest,
    BackupRequestResource,
    BackupResourceConfig,
    BackupResourceConfigResource,
    BackupResourceEncryptionConfig,
    BackupResourceEncryptionConfigExtended,
    BackupResourceEncryptionConfigExtendedResource,
    BackupResourceEncryptionConfigResource,
    BackupResourceVaultConfig,
    BackupResourceVaultConfigResource,
    BackupStatusRequest,
    BackupStatusResponse,
    ClientDiscoveryDisplay,
    ClientDiscoveryForLogSpecification,
    ClientDiscoveryForProperties,
    ClientDiscoveryForServiceSpecification,
    ClientDiscoveryValueForSingleApi,
    ClientScriptForConnect,
    ContainerIdentityInfo,
    DPMContainerExtendedInfo,
    DPMProtectedItem,
    DPMProtectedItemExtendedInfo,
    DailyRetentionFormat,
    DailyRetentionSchedule,
    DailySchedule,
    DatabaseInRP,
    Day,
    DiskExclusionProperties,
    DiskInformation,
    DistributedNodesInfo,
    DpmBackupEngine,
    DpmContainer,
    DpmErrorInfo,
    DpmJob,
    DpmJobExtendedInfo,
    DpmJobTaskDetails,
    EncryptionDetails,
    ErrorAdditionalInfo,
    ErrorDetail,
    ErrorResponse,
    ExportJobsOperationResultInfo,
    ExtendedLocation,
    ExtendedProperties,
    FeatureSupportRequest,
    FetchTieringCostInfoForRehydrationRequest,
    FetchTieringCostInfoRequest,
    FetchTieringCostSavingsInfoForPolicyRequest,
    FetchTieringCostSavingsInfoForProtectedItemRequest,
    FetchTieringCostSavingsInfoForVaultRequest,
    GenericContainer,
    GenericContainerExtendedInfo,
    GenericProtectedItem,
    GenericProtectionPolicy,
    GenericRecoveryPoint,
    HourlySchedule,
    ILRRequest,
    ILRRequestResource,
    IaaSVMContainer,
    IaaSVMProtectableItem,
    IaasVMBackupRequest,
    IaasVMILRRegistrationRequest,
    IaasVMRecoveryPoint,
    IaasVMRestoreRequest,
    IaasVMRestoreWithRehydrationRequest,
    IdentityBasedRestoreDetails,
    IdentityInfo,
    InquiryInfo,
    InquiryValidation,
    InstantItemRecoveryTarget,
    InstantRPAdditionalDetails,
    Job,
    JobResource,
    KEKDetails,
    KPIResourceHealthDetails,
    KeyAndSecretDetails,
    ListRecoveryPointsRecommendedForMoveRequest,
    LogSchedulePolicy,
    LongTermRetentionPolicy,
    LongTermSchedulePolicy,
    MABContainerHealthDetails,
    MabContainer,
    MabContainerExtendedInfo,
    MabErrorInfo,
    MabFileFolderProtectedItem,
    MabFileFolderProtectedItemExtendedInfo,
    MabJob,
    MabJobExtendedInfo,
    MabJobTaskDetails,
    MabProtectionPolicy,
    MonthlyRetentionSchedule,
    MoveRPAcrossTiersRequest,
    NameInfo,
    OperationResultInfo,
    OperationResultInfoBase,
    OperationResultInfoBaseResource,
    OperationStatus,
    OperationStatusError,
    OperationStatusExtendedInfo,
    OperationStatusJobExtendedInfo,
    OperationStatusJobsExtendedInfo,
    OperationStatusProvisionILRExtendedInfo,
    OperationStatusValidateOperationExtendedInfo,
    OperationWorkerResponse,
    PatchRecoveryPointInput,
    PatchRecoveryPointPropertiesInput,
    PointInTimeRange,
    PreBackupValidation,
    PreValidateEnableBackupRequest,
    PreValidateEnableBackupResponse,
    PrepareDataMoveRequest,
    PrepareDataMoveResponse,
    PrivateEndpoint,
    PrivateEndpointConnection,
    PrivateEndpointConnectionResource,
    PrivateLinkServiceConnectionState,
    ProtectableContainer,
    ProtectableContainerResource,
    ProtectedItem,
    ProtectedItemResource,
    ProtectionContainer,
    ProtectionContainerResource,
    ProtectionIntent,
    ProtectionIntentResource,
    ProtectionPolicy,
    ProtectionPolicyResource,
    ProxyResource,
    RecoveryPoint,
    RecoveryPointDiskConfiguration,
    RecoveryPointMoveReadinessInfo,
    RecoveryPointProperties,
    RecoveryPointRehydrationInfo,
    RecoveryPointResource,
    RecoveryPointTierInformation,
    RecoveryPointTierInformationV2,
    Resource,
    ResourceGuardOperationDetail,
    ResourceGuardProxyBase,
    ResourceGuardProxyBaseResource,
    ResourceHealthDetails,
    ResourceList,
    RestoreFileSpecs,
    RestoreRequest,
    RestoreRequestResource,
    RetentionDuration,
    RetentionPolicy,
    SQLDataDirectory,
    SQLDataDirectoryMapping,
    SchedulePolicy,
    SecuredVMDetails,
    SecurityPinBase,
    Settings,
    SimpleRetentionPolicy,
    SimpleSchedulePolicy,
    SimpleSchedulePolicyV2,
    SnapshotBackupAdditionalDetails,
    SnapshotRestoreParameters,
    SourceSideScanInfo,
    SubProtectionPolicy,
    SystemData,
    TargetAFSRestoreInfo,
    TargetDiskNetworkAccessSettings,
    TargetRestoreInfo,
    ThreatInfo,
    TieringCostInfo,
    TieringCostRehydrationInfo,
    TieringCostSavingInfo,
    TieringPolicy,
    TokenInformation,
    TriggerDataMoveRequest,
    UnlockDeleteRequest,
    UnlockDeleteResponse,
    UpdateRecoveryPointRequest,
    UserAssignedIdentityProperties,
    UserAssignedManagedIdentityDetails,
    ValidateIaasVMRestoreOperationRequest,
    ValidateOperationRequest,
    ValidateOperationRequestResource,
    ValidateOperationResponse,
    ValidateOperationsResponse,
    ValidateRestoreOperationRequest,
    VaultJob,
    VaultJobErrorInfo,
    VaultJobExtendedInfo,
    VaultRetentionPolicy,
    VaultStorageConfigOperationResultResponse,
    WeeklyRetentionFormat,
    WeeklyRetentionSchedule,
    WeeklySchedule,
    WorkloadInquiryDetails,
    WorkloadItem,
    WorkloadItemResource,
    WorkloadProtectableItem,
    WorkloadProtectableItemResource,
    YearlyRetentionSchedule,
)

from ._enums import (  # type: ignore
    AcquireStorageAccountLock,
    AzureFileShareType,
    BackupEngineType,
    BackupItemType,
    BackupManagementType,
    BackupType,
    CopyOptions,
    CreateMode,
    CreatedByType,
    DataMoveLevel,
    DataSourceType,
    DayOfWeek,
    DedupState,
    EncryptionAtRestType,
    EnhancedSecurityState,
    FabricName,
    HealthStatus,
    HttpStatusCode,
    IAASVMPolicyType,
    IaasVMSnapshotConsistencyType,
    InfrastructureEncryptionState,
    InquiryStatus,
    InstanceProtectionReadiness,
    JobSupportedAction,
    LastBackupStatus,
    LastUpdateStatus,
    MabServerType,
    MonthOfYear,
    OperationStatusValues,
    OperationType,
    OverwriteOptions,
    PolicyType,
    PrivateEndpointConnectionStatus,
    ProtectableContainerType,
    ProtectedItemHealthStatus,
    ProtectedItemState,
    ProtectionIntentItemType,
    ProtectionLevel,
    ProtectionState,
    ProtectionStatus,
    ProvisioningState,
    RecoveryMode,
    RecoveryPointTierStatus,
    RecoveryPointTierType,
    RecoveryType,
    RehydrationPriority,
    ResourceHealthStatus,
    RestorePointType,
    RestoreRequestType,
    RetentionDurationType,
    RetentionScheduleFormat,
    SQLDataDirectoryType,
    ScheduleRunType,
    SoftDeleteFeatureState,
    SourceSideScanStatus,
    SourceSideScanSummary,
    StorageType,
    StorageTypeState,
    SupportStatus,
    TargetDiskNetworkAccessOption,
    ThreatSeverity,
    ThreatState,
    ThreatStatus,
    TieringMode,
    UsagesUnit,
    VMWorkloadPolicyType,
    ValidationStatus,
    VaultSubResourceType,
    WeekOfMonth,
    WorkloadItemType,
    WorkloadType,
    XcoolState,
)
from ._patch import __all__ as _patch_all
from ._patch import *
from ._patch import patch_sdk as _patch_sdk

__all__ = [
    "ArmErrorDetail",
    "AzureBackupGoalFeatureSupportRequest",
    "AzureBackupServerContainer",
    "AzureBackupServerEngine",
    "AzureFileShareBackupRequest",
    "AzureFileShareProtectableItem",
    "AzureFileShareProtectionPolicy",
    "AzureFileShareProvisionILRRequest",
    "AzureFileShareRecoveryPoint",
    "AzureFileShareRestoreRequest",
    "AzureFileshareProtectedItem",
    "AzureFileshareProtectedItemExtendedInfo",
    "AzureIaaSClassicComputeVMContainer",
    "AzureIaaSClassicComputeVMProtectableItem",
    "AzureIaaSClassicComputeVMProtectedItem",
    "AzureIaaSComputeVMContainer",
    "AzureIaaSComputeVMProtectableItem",
    "AzureIaaSComputeVMProtectedItem",
    "AzureIaaSVMErrorInfo",
    "AzureIaaSVMHealthDetails",
    "AzureIaaSVMJob",
    "AzureIaaSVMJobExtendedInfo",
    "AzureIaaSVMJobTaskDetails",
    "AzureIaaSVMJobV2",
    "AzureIaaSVMProtectedItem",
    "AzureIaaSVMProtectedItemExtendedInfo",
    "AzureIaaSVMProtectionPolicy",
    "AzureRecoveryServiceVaultProtectionIntent",
    "AzureResourceProtectionIntent",
    "AzureSQLAGWorkloadContainerProtectionContainer",
    "AzureSqlContainer",
    "AzureSqlProtectedItem",
    "AzureSqlProtectedItemExtendedInfo",
    "AzureSqlProtectionPolicy",
    "AzureStorageContainer",
    "AzureStorageErrorInfo",
    "AzureStorageJob",
    "AzureStorageJobExtendedInfo",
    "AzureStorageJobTaskDetails",
    "AzureStorageProtectableContainer",
    "AzureVMAppContainerProtectableContainer",
    "AzureVMAppContainerProtectionContainer",
    "AzureVMResourceFeatureSupportRequest",
    "AzureVMResourceFeatureSupportResponse",
    "AzureVmWorkloadItem",
    "AzureVmWorkloadProtectableItem",
    "AzureVmWorkloadProtectedItem",
    "AzureVmWorkloadProtectedItemExtendedInfo",
    "AzureVmWorkloadProtectionPolicy",
    "AzureVmWorkloadSAPAseDatabaseProtectableItem",
    "AzureVmWorkloadSAPAseDatabaseProtectedItem",
    "AzureVmWorkloadSAPAseDatabaseWorkloadItem",
    "AzureVmWorkloadSAPAseSystemProtectableItem",
    "AzureVmWorkloadSAPAseSystemWorkloadItem",
    "AzureVmWorkloadSAPHanaDBInstance",
    "AzureVmWorkloadSAPHanaDBInstanceProtectedItem",
    "AzureVmWorkloadSAPHanaDatabaseProtectableItem",
    "AzureVmWorkloadSAPHanaDatabaseProtectedItem",
    "AzureVmWorkloadSAPHanaDatabaseWorkloadItem",
    "AzureVmWorkloadSAPHanaHSRProtectableItem",
    "AzureVmWorkloadSAPHanaScaleoutProtectableItem",
    "AzureVmWorkloadSAPHanaSystemProtectableItem",
    "AzureVmWorkloadSAPHanaSystemWorkloadItem",
    "AzureVmWorkloadSQLAvailabilityGroupProtectableItem",
    "AzureVmWorkloadSQLDatabaseProtectableItem",
    "AzureVmWorkloadSQLDatabaseProtectedItem",
    "AzureVmWorkloadSQLDatabaseWorkloadItem",
    "AzureVmWorkloadSQLInstanceProtectableItem",
    "AzureVmWorkloadSQLInstanceProtectedItem",
    "AzureVmWorkloadSQLInstanceWorkloadItem",
    "AzureWorkloadAutoProtectionIntent",
    "AzureWorkloadBackupRequest",
    "AzureWorkloadContainer",
    "AzureWorkloadContainerAutoProtectionIntent",
    "AzureWorkloadContainerExtendedInfo",
    "AzureWorkloadErrorInfo",
    "AzureWorkloadJob",
    "AzureWorkloadJobExtendedInfo",
    "AzureWorkloadJobTaskDetails",
    "AzureWorkloadPointInTimeRecoveryPoint",
    "AzureWorkloadPointInTimeRestoreRequest",
    "AzureWorkloadRecoveryPoint",
    "AzureWorkloadRestoreRequest",
    "AzureWorkloadSAPAsePointInTimeRecoveryPoint",
    "AzureWorkloadSAPAsePointInTimeRestoreRequest",
    "AzureWorkloadSAPAseRecoveryPoint",
    "AzureWorkloadSAPAseRestoreRequest",
    "AzureWorkloadSAPHanaPointInTimeRecoveryPoint",
    "AzureWorkloadSAPHanaPointInTimeRestoreRequest",
    "AzureWorkloadSAPHanaPointInTimeRestoreWithRehydrateRequest",
    "AzureWorkloadSAPHanaRecoveryPoint",
    "AzureWorkloadSAPHanaRestoreRequest",
    "AzureWorkloadSAPHanaRestoreWithRehydrateRequest",
    "AzureWorkloadSQLAutoProtectionIntent",
    "AzureWorkloadSQLPointInTimeRecoveryPoint",
    "AzureWorkloadSQLPointInTimeRestoreRequest",
    "AzureWorkloadSQLPointInTimeRestoreWithRehydrateRequest",
    "AzureWorkloadSQLRecoveryPoint",
    "AzureWorkloadSQLRecoveryPointExtendedInfo",
    "AzureWorkloadSQLRestoreRequest",
    "AzureWorkloadSQLRestoreWithRehydrateRequest",
    "BEKDetails",
    "BackupEngineBase",
    "BackupEngineBaseResource",
    "BackupEngineExtendedInfo",
    "BackupManagementUsage",
    "BackupRequest",
    "BackupRequestResource",
    "BackupResourceConfig",
    "BackupResourceConfigResource",
    "BackupResourceEncryptionConfig",
    "BackupResourceEncryptionConfigExtended",
    "BackupResourceEncryptionConfigExtendedResource",
    "BackupResourceEncryptionConfigResource",
    "BackupResourceVaultConfig",
    "BackupResourceVaultConfigResource",
    "BackupStatusRequest",
    "BackupStatusResponse",
    "ClientDiscoveryDisplay",
    "ClientDiscoveryForLogSpecification",
    "ClientDiscoveryForProperties",
    "ClientDiscoveryForServiceSpecification",
    "ClientDiscoveryValueForSingleApi",
    "ClientScriptForConnect",
    "ContainerIdentityInfo",
    "DPMContainerExtendedInfo",
    "DPMProtectedItem",
    "DPMProtectedItemExtendedInfo",
    "DailyRetentionFormat",
    "DailyRetentionSchedule",
    "DailySchedule",
    "DatabaseInRP",
    "Day",
    "DiskExclusionProperties",
    "DiskInformation",
    "DistributedNodesInfo",
    "DpmBackupEngine",
    "DpmContainer",
    "DpmErrorInfo",
    "DpmJob",
    "DpmJobExtendedInfo",
    "DpmJobTaskDetails",
    "EncryptionDetails",
    "ErrorAdditionalInfo",
    "ErrorDetail",
    "ErrorResponse",
    "ExportJobsOperationResultInfo",
    "ExtendedLocation",
    "ExtendedProperties",
    "FeatureSupportRequest",
    "FetchTieringCostInfoForRehydrationRequest",
    "FetchTieringCostInfoRequest",
    "FetchTieringCostSavingsInfoForPolicyRequest",
    "FetchTieringCostSavingsInfoForProtectedItemRequest",
    "FetchTieringCostSavingsInfoForVaultRequest",
    "GenericContainer",
    "GenericContainerExtendedInfo",
    "GenericProtectedItem",
    "GenericProtectionPolicy",
    "GenericRecoveryPoint",
    "HourlySchedule",
    "ILRRequest",
    "ILRRequestResource",
    "IaaSVMContainer",
    "IaaSVMProtectableItem",
    "IaasVMBackupRequest",
    "IaasVMILRRegistrationRequest",
    "IaasVMRecoveryPoint",
    "IaasVMRestoreRequest",
    "IaasVMRestoreWithRehydrationRequest",
    "IdentityBasedRestoreDetails",
    "IdentityInfo",
    "InquiryInfo",
    "InquiryValidation",
    "InstantItemRecoveryTarget",
    "InstantRPAdditionalDetails",
    "Job",
    "JobResource",
    "KEKDetails",
    "KPIResourceHealthDetails",
    "KeyAndSecretDetails",
    "ListRecoveryPointsRecommendedForMoveRequest",
    "LogSchedulePolicy",
    "LongTermRetentionPolicy",
    "LongTermSchedulePolicy",
    "MABContainerHealthDetails",
    "MabContainer",
    "MabContainerExtendedInfo",
    "MabErrorInfo",
    "MabFileFolderProtectedItem",
    "MabFileFolderProtectedItemExtendedInfo",
    "MabJob",
    "MabJobExtendedInfo",
    "MabJobTaskDetails",
    "MabProtectionPolicy",
    "MonthlyRetentionSchedule",
    "MoveRPAcrossTiersRequest",
    "NameInfo",
    "OperationResultInfo",
    "OperationResultInfoBase",
    "OperationResultInfoBaseResource",
    "OperationStatus",
    "OperationStatusError",
    "OperationStatusExtendedInfo",
    "OperationStatusJobExtendedInfo",
    "OperationStatusJobsExtendedInfo",
    "OperationStatusProvisionILRExtendedInfo",
    "OperationStatusValidateOperationExtendedInfo",
    "OperationWorkerResponse",
    "PatchRecoveryPointInput",
    "PatchRecoveryPointPropertiesInput",
    "PointInTimeRange",
    "PreBackupValidation",
    "PreValidateEnableBackupRequest",
    "PreValidateEnableBackupResponse",
    "PrepareDataMoveRequest",
    "PrepareDataMoveResponse",
    "PrivateEndpoint",
    "PrivateEndpointConnection",
    "PrivateEndpointConnectionResource",
    "PrivateLinkServiceConnectionState",
    "ProtectableContainer",
    "ProtectableContainerResource",
    "ProtectedItem",
    "ProtectedItemResource",
    "ProtectionContainer",
    "ProtectionContainerResource",
    "ProtectionIntent",
    "ProtectionIntentResource",
    "ProtectionPolicy",
    "ProtectionPolicyResource",
    "ProxyResource",
    "RecoveryPoint",
    "RecoveryPointDiskConfiguration",
    "RecoveryPointMoveReadinessInfo",
    "RecoveryPointProperties",
    "RecoveryPointRehydrationInfo",
    "RecoveryPointResource",
    "RecoveryPointTierInformation",
    "RecoveryPointTierInformationV2",
    "Resource",
    "ResourceGuardOperationDetail",
    "ResourceGuardProxyBase",
    "ResourceGuardProxyBaseResource",
    "ResourceHealthDetails",
    "ResourceList",
    "RestoreFileSpecs",
    "RestoreRequest",
    "RestoreRequestResource",
    "RetentionDuration",
    "RetentionPolicy",
    "SQLDataDirectory",
    "SQLDataDirectoryMapping",
    "SchedulePolicy",
    "SecuredVMDetails",
    "SecurityPinBase",
    "Settings",
    "SimpleRetentionPolicy",
    "SimpleSchedulePolicy",
    "SimpleSchedulePolicyV2",
    "SnapshotBackupAdditionalDetails",
    "SnapshotRestoreParameters",
    "SourceSideScanInfo",
    "SubProtectionPolicy",
    "SystemData",
    "TargetAFSRestoreInfo",
    "TargetDiskNetworkAccessSettings",
    "TargetRestoreInfo",
    "ThreatInfo",
    "TieringCostInfo",
    "TieringCostRehydrationInfo",
    "TieringCostSavingInfo",
    "TieringPolicy",
    "TokenInformation",
    "TriggerDataMoveRequest",
    "UnlockDeleteRequest",
    "UnlockDeleteResponse",
    "UpdateRecoveryPointRequest",
    "UserAssignedIdentityProperties",
    "UserAssignedManagedIdentityDetails",
    "ValidateIaasVMRestoreOperationRequest",
    "ValidateOperationRequest",
    "ValidateOperationRequestResource",
    "ValidateOperationResponse",
    "ValidateOperationsResponse",
    "ValidateRestoreOperationRequest",
    "VaultJob",
    "VaultJobErrorInfo",
    "VaultJobExtendedInfo",
    "VaultRetentionPolicy",
    "VaultStorageConfigOperationResultResponse",
    "WeeklyRetentionFormat",
    "WeeklyRetentionSchedule",
    "WeeklySchedule",
    "WorkloadInquiryDetails",
    "WorkloadItem",
    "WorkloadItemResource",
    "WorkloadProtectableItem",
    "WorkloadProtectableItemResource",
    "YearlyRetentionSchedule",
    "AcquireStorageAccountLock",
    "AzureFileShareType",
    "BackupEngineType",
    "BackupItemType",
    "BackupManagementType",
    "BackupType",
    "CopyOptions",
    "CreateMode",
    "CreatedByType",
    "DataMoveLevel",
    "DataSourceType",
    "DayOfWeek",
    "DedupState",
    "EncryptionAtRestType",
    "EnhancedSecurityState",
    "FabricName",
    "HealthStatus",
    "HttpStatusCode",
    "IAASVMPolicyType",
    "IaasVMSnapshotConsistencyType",
    "InfrastructureEncryptionState",
    "InquiryStatus",
    "InstanceProtectionReadiness",
    "JobSupportedAction",
    "LastBackupStatus",
    "LastUpdateStatus",
    "MabServerType",
    "MonthOfYear",
    "OperationStatusValues",
    "OperationType",
    "OverwriteOptions",
    "PolicyType",
    "PrivateEndpointConnectionStatus",
    "ProtectableContainerType",
    "ProtectedItemHealthStatus",
    "ProtectedItemState",
    "ProtectionIntentItemType",
    "ProtectionLevel",
    "ProtectionState",
    "ProtectionStatus",
    "ProvisioningState",
    "RecoveryMode",
    "RecoveryPointTierStatus",
    "RecoveryPointTierType",
    "RecoveryType",
    "RehydrationPriority",
    "ResourceHealthStatus",
    "RestorePointType",
    "RestoreRequestType",
    "RetentionDurationType",
    "RetentionScheduleFormat",
    "SQLDataDirectoryType",
    "ScheduleRunType",
    "SoftDeleteFeatureState",
    "SourceSideScanStatus",
    "SourceSideScanSummary",
    "StorageType",
    "StorageTypeState",
    "SupportStatus",
    "TargetDiskNetworkAccessOption",
    "ThreatSeverity",
    "ThreatState",
    "ThreatStatus",
    "TieringMode",
    "UsagesUnit",
    "VMWorkloadPolicyType",
    "ValidationStatus",
    "VaultSubResourceType",
    "WeekOfMonth",
    "WorkloadItemType",
    "WorkloadType",
    "XcoolState",
]
__all__.extend([p for p in _patch_all if p not in __all__])  # pyright: ignore
_patch_sdk()
